Derivcheck provides a robust and very sensitive checker of analytic partial derivates.
It is intended to be used in unit tests of other projects. See `basic_example.py` for a
basic example.

Installation
============

Derivcheck can be installed with pip:

    pip install derivcheck


Description of the algorithm
============================

TODO
